Consulting and more — influx_si 5.0 documentation

# Consulting and more

If you need help in design, conducting and interpretation of label experiments, you can expose your problem in a brief email to our platform MetaToul (metatoul [at] insa-toulouse [dot] fr) located in Toulouse, France. A dedicated person will take contact with your to detail what can be done to help you and to draw up a quote.

You don’t have to ask for a consulting for a simple bug submission. A bug submission can be directly made to sokol [at] insa-toulouse [dot] fr.

For more details about the platform MetaToul, you can visit our web site http://www.metatoul.fr (english version is available).